==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/prometheus/BucketsDefinitionFluent.java <==
package me.snowdrop.istio.mixer.adapter.prometheus;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public interface BucketsDefinitionFluent<A extends BucketsDefinitionFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildDefinition instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.mixer.adapter.prometheus.BucketsDefinition.Definition getDefinition();
    public me.snowdrop.istio.mixer.adapter.prometheus.BucketsDefinition.Definition buildDefinition();
    public A withDefinition(me.snowdrop.istio.mixer.adapter.prometheus.BucketsDefinition.Definition definition);
    public Boolean hasDefinition();
    public A withExponentialBucketsDefinition(ExponentialBucketsDefinition exponentialBucketsDefinition);
    public BucketsDefinitionFluent.ExponentialBucketsDefinitionNested<A> withNewExponentialBucketsDefinition();
    public BucketsDefinitionFluent.ExponentialBucketsDefinitionNested<A> withNewExponentialBucketsDefinitionLike(ExponentialBucketsDefinition item);
    public A withLinearBucketsDefinition(LinearBucketsDefinition linearBucketsDefinition);
    public BucketsDefinitionFluent.LinearBucketsDefinitionNested<A> withNewLinearBucketsDefinition();
    public BucketsDefinitionFluent.LinearBucketsDefinitionNested<A> withNewLinearBucketsDefinitionLike(LinearBucketsDefinition item);
    public A withExplicitBucketsDefinition(ExplicitBucketsDefinition explicitBucketsDefinition);
    public BucketsDefinitionFluent.ExplicitBucketsDefinitionNested<A> withNewExplicitBucketsDefinition();
    public BucketsDefinitionFluent.ExplicitBucketsDefinitionNested<A> withNewExplicitBucketsDefinitionLike(ExplicitBucketsDefinition item);

    public interface ExponentialBucketsDefinitionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExponentialBucketsDefinitionFluent<BucketsDefinitionFluent.ExponentialBucketsDefinitionNested<N>>{

        
    public N and();    public N endExponentialBucketsDefinition();
}
    public interface LinearBucketsDefinitionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LinearBucketsDefinitionFluent<BucketsDefinitionFluent.LinearBucketsDefinitionNested<N>>{

        
    public N and();    public N endLinearBucketsDefinition();
}
    public interface ExplicitBucketsDefinitionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExplicitBucketsDefinitionFluent<BucketsDefinitionFluent.ExplicitBucketsDefinitionNested<N>>{

        
    public N and();    public N endExplicitBucketsDefinition();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/prometheus/BucketsDefinitionFluent.java <==
package me.snowdrop.istio.mixer.adapter.prometheus;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public interface BucketsDefinitionFluent<A extends BucketsDefinitionFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildDefinition instead.
 * @return The buildable object.
 */
@Deprecated public BucketsDefinition.Definition getDefinition();
    public BucketsDefinition.Definition buildDefinition();
    public A withDefinition(BucketsDefinition.Definition definition);
    public Boolean hasDefinition();
    public A withExponentialBucketsDefinition(ExponentialBucketsDefinition exponentialBucketsDefinition);
    public BucketsDefinitionFluent.ExponentialBucketsDefinitionNested<A> withNewExponentialBucketsDefinition();
    public BucketsDefinitionFluent.ExponentialBucketsDefinitionNested<A> withNewExponentialBucketsDefinitionLike(ExponentialBucketsDefinition item);
    public A withLinearBucketsDefinition(LinearBucketsDefinition linearBucketsDefinition);
    public BucketsDefinitionFluent.LinearBucketsDefinitionNested<A> withNewLinearBucketsDefinition();
    public BucketsDefinitionFluent.LinearBucketsDefinitionNested<A> withNewLinearBucketsDefinitionLike(LinearBucketsDefinition item);
    public A withExplicitBucketsDefinition(ExplicitBucketsDefinition explicitBucketsDefinition);
    public BucketsDefinitionFluent.ExplicitBucketsDefinitionNested<A> withNewExplicitBucketsDefinition();
    public BucketsDefinitionFluent.ExplicitBucketsDefinitionNested<A> withNewExplicitBucketsDefinitionLike(ExplicitBucketsDefinition item);

    public interface ExponentialBucketsDefinitionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExponentialBucketsDefinitionFluent<BucketsDefinitionFluent.ExponentialBucketsDefinitionNested<N>>{

        
    public N and();    public N endExponentialBucketsDefinition();
}
    public interface LinearBucketsDefinitionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LinearBucketsDefinitionFluent<BucketsDefinitionFluent.LinearBucketsDefinitionNested<N>>{

        
    public N and();    public N endLinearBucketsDefinition();
}
    public interface ExplicitBucketsDefinitionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExplicitBucketsDefinitionFluent<BucketsDefinitionFluent.ExplicitBucketsDefinitionNested<N>>{

        
    public N and();    public N endExplicitBucketsDefinition();
}


}
